/* Fonts */

@font-face {
    font-family: 'RobotoRegular';
    src: url('../base/fonts/Roboto-Regular-webfont.eot');
    src: url('../base/fonts/Roboto-Regular-webfont.eot?#iefix') format('embedded-opentype'),
    url('../base/fonts/Roboto-Regular-webfont.woff') format('woff'),
    url('../base/fonts/Roboto-Regular-webfont.ttf') format('truetype'),
    url('../base/fonts/Roboto-Regular-webfont.svg#RobotoRegular') format('svg');
    font-weight: normal;
    font-style: normal;

}

@font-face {
    font-family: 'RobotoItalic';
    src: url('../base/fonts/Roboto-Italic-webfont.eot');
    src: url('../base/fonts/Roboto-Italic-webfont.eot?#iefix') format('embedded-opentype'),
    url('../base/fonts/Roboto-Italic-webfont.woff') format('woff'),
    url('../base/fonts/Roboto-Italic-webfont.ttf') format('truetype'),
    url('../base/fonts/Roboto-Italic-webfont.svg#RobotoItalic') format('svg');
    font-weight: normal;
    font-style: normal;

}

@font-face {
    font-family: 'RobotoBold';
    src: url('../base/fonts/Roboto-Bold-webfont.eot');
    src: url('../base/fonts/Roboto-Bold-webfont.eot?#iefix') format('embedded-opentype'),
    url('../base/fonts/Roboto-Bold-webfont.woff') format('woff'),
    url('../base/fonts/Roboto-Bold-webfont.ttf') format('truetype'),
    url('../base/fonts/Roboto-Bold-webfont.svg#RobotoBold') format('svg');
    font-weight: normal;
    font-style: normal;

}

@font-face {
    font-family: 'RobotoBoldItalic';
    src: url('../base/fonts/Roboto-BoldItalic-webfont.eot');
    src: url('../base/fonts/Roboto-BoldItalic-webfont.eot?#iefix') format('embedded-opentype'),
    url('../base/fonts/Roboto-BoldItalic-webfont.woff') format('woff'),
    url('../base/fonts/Roboto-BoldItalic-webfont.ttf') format('truetype'),
    url('../base/fonts/Roboto-BoldItalic-webfont.svg#RobotoBoldItalic') format('svg');
    font-weight: normal;
    font-style: normal;

}

@font-face {
    font-family: 'RobotoCondensed';
    src: url('../base/fonts/Roboto-Condensed-webfont.eot');
    src: url('../base/fonts/Roboto-Condensed-webfont.eot?#iefix') format('embedded-opentype'),
    url('../base/fonts/Roboto-Condensed-webfont.woff') format('woff'),
    url('../base/fonts/Roboto-Condensed-webfont.ttf') format('truetype'),
    url('../base/fonts/Roboto-Condensed-webfont.svg#RobotoCondensed') format('svg');
    font-weight: normal;
    font-style: normal;

}

@font-face {
    font-family: 'RobotoCondensedItalic';
    src: url('../base/fonts/Roboto-CondensedItalic-webfont.eot');
    src: url('../base/fonts/Roboto-CondensedItalic-webfont.eot?#iefix') format('embedded-opentype'),
    url('../base/fonts/Roboto-CondensedItalic-webfont.woff') format('woff'),
    url('../base/fonts/Roboto-CondensedItalic-webfont.ttf') format('truetype'),
    url('../base/fonts/Roboto-CondensedItalic-webfont.svg#RobotoCondensedItalic') format('svg');
    font-weight: normal;
    font-style: normal;

}

@font-face {
    font-family: 'RobotoBoldCondensed';
    src: url('../base/fonts/Roboto-BoldCondensed-webfont.eot');
    src: url('../base/fonts/Roboto-BoldCondensed-webfont.eot?#iefix') format('embedded-opentype'),
    url('../base/fonts/Roboto-BoldCondensed-webfont.woff') format('woff'),
    url('../base/fonts/Roboto-BoldCondensed-webfont.ttf') format('truetype'),
    url('../base/fonts/Roboto-BoldCondensed-webfont.svg#RobotoBoldCondensed') format('svg');
    font-weight: normal;
    font-style: normal;

}

@font-face {
    font-family: 'RobotoBoldCondensedItalic';
    src: url('../base/fonts/Roboto-BoldCondensedItalic-webfont.eot');
    src: url('../base/fonts/Roboto-BoldCondensedItalic-webfont.eot?#iefix') format('embedded-opentype'),
    url('../base/fonts/Roboto-BoldCondensedItalic-webfont.woff') format('woff'),
    url('../base/fonts/Roboto-BoldCondensedItalic-webfont.ttf') format('truetype'),
    url('../base/fonts/Roboto-BoldCondensedItalic-webfont.svg#RobotoBoldCondensedItalic') format('svg');
    font-weight: normal;
    font-style: normal;

}

@font-face {
    font-family: 'RobotoThin';
    src: url('../base/fonts/Roboto-Thin-webfont.eot');
    src: url('../base/fonts/Roboto-Thin-webfont.eot?#iefix') format('embedded-opentype'),
    url('../base/fonts/Roboto-Thin-webfont.woff') format('woff'),
    url('../base/fonts/Roboto-Thin-webfont.ttf') format('truetype'),
    url('../base/fonts/Roboto-Thin-webfont.svg#RobotoThin') format('svg');
    font-weight: normal;
    font-style: normal;

}

@font-face {
    font-family: 'RobotoThinItalic';
    src: url('../base/fonts/Roboto-ThinItalic-webfont.eot');
    src: url('../base/fonts/Roboto-ThinItalic-webfont.eot?#iefix') format('embedded-opentype'),
    url('../base/fonts/Roboto-ThinItalic-webfont.woff') format('woff'),
    url('../base/fonts/Roboto-ThinItalic-webfont.ttf') format('truetype'),
    url('../base/fonts/Roboto-ThinItalic-webfont.svg#RobotoThinItalic') format('svg');
    font-weight: normal;
    font-style: normal;

}

@font-face {
    font-family: 'RobotoLight';
    src: url('../base/fonts/Roboto-Light-webfont.eot');
    src: url('../base/fonts/Roboto-Light-webfont.eot?#iefix') format('embedded-opentype'),
    url('../base/fonts/Roboto-Light-webfont.woff') format('woff'),
    url('../base/fonts/Roboto-Light-webfont.ttf') format('truetype'),
    url('../base/fonts/Roboto-Light-webfont.svg#RobotoLight') format('svg');
    font-weight: normal;
    font-style: normal;

}

@font-face {
    font-family: 'RobotoLightItalic';
    src: url('../base/fonts/Roboto-LightItalic-webfont.eot');
    src: url('../base/fonts/Roboto-LightItalic-webfont.eot?#iefix') format('embedded-opentype'),
    url('../base/fonts/Roboto-LightItalic-webfont.woff') format('woff'),
    url('../base/fonts/Roboto-LightItalic-webfont.ttf') format('truetype'),
    url('../base/fonts/Roboto-LightItalic-webfont.svg#RobotoLightItalic') format('svg');
    font-weight: normal;
    font-style: normal;

}

@font-face {
    font-family: 'RobotoMedium';
    src: url('../base/fonts/Roboto-Medium-webfont.eot');
    src: url('../base/fonts/Roboto-Medium-webfont.eot?#iefix') format('embedded-opentype'),
    url('../base/fonts/Roboto-Medium-webfont.woff') format('woff'),
    url('../base/fonts/Roboto-Medium-webfont.ttf') format('truetype'),
    url('../base/fonts/Roboto-Medium-webfont.svg#RobotoMedium') format('svg');
    font-weight: normal;
    font-style: normal;

}

@font-face {
    font-family: 'RobotoMediumItalic';
    src: url('../base/fonts/Roboto-MediumItalic-webfont.eot');
    src: url('../base/fonts/Roboto-MediumItalic-webfont.eot?#iefix') format('embedded-opentype'),
    url('../base/fonts/Roboto-MediumItalic-webfont.woff') format('woff'),
    url('../base/fonts/Roboto-MediumItalic-webfont.ttf') format('truetype'),
    url('../base/fonts/Roboto-MediumItalic-webfont.svg#RobotoMediumItalic') format('svg');
    font-weight: normal;
    font-style: normal;

}

@font-face {
    font-family: 'RobotoBlack';
    src: url('../base/fonts/Roboto-Black-webfont.eot');
    src: url('../base/fonts/Roboto-Black-webfont.eot?#iefix') format('embedded-opentype'),
    url('../base/fonts/Roboto-Black-webfont.woff') format('woff'),
    url('../base/fonts/Roboto-Black-webfont.ttf') format('truetype'),
    url('../base/fonts/Roboto-Black-webfont.svg#RobotoBlack') format('svg');
    font-weight: normal;
    font-style: normal;

}

@font-face {
    font-family: 'RobotoBlackItalic';
    src: url('../base/fonts/Roboto-BlackItalic-webfont.eot');
    src: url('../base/fonts/Roboto-BlackItalic-webfont.eot?#iefix') format('embedded-opentype'),
    url('../base/fonts/Roboto-BlackItalic-webfont.woff') format('woff'),
    url('../base/fonts/Roboto-BlackItalic-webfont.ttf') format('truetype'),
    url('../base/fonts/Roboto-BlackItalic-webfont.svg#RobotoBlackItalic') format('svg');
    font-weight: normal;
    font-style: normal;

}
