/*
NOTE: Compile with less -x and paste into embed.html when modified.
*/

#djedi-cms {
  position: fixed;
  top: 0;
  right: -400px;
  width: 400px;
  height: 100%;
  border: 0;
  z-index: 30000;

  &.fullscreen {
      width: 100%;
  }

  &.closed {
      opacity: 0.5;
  }

  &.closed:hover {
      opacity: 1;
  }
}

/* Editable area (outline) */

.djedi-node-outline {
  position: absolute;
  z-index: 20000;
  border-radius: 4px;
  cursor: pointer;

  &:hover {
    opacity: 0.25;
    background-color: lightseagreen;
  }

  &.visible {
    opacity: 0.25;
    background-color: lightseagreen;

    &:hover {
      opacity: 0.5;
    }
  }

  &.selected {
    opacity: 1;
    background-color: transparent;
    -webkit-box-shadow: 0px 0px 20px 3px rgba(0, 220, 255, 0.5), inset 0px 0px 0px 2px rgba(0, 220, 255, 1);
            box-shadow: 0px 0px 20px 3px rgba(0, 220, 255, 0.5), inset 0px 0px 0px 2px rgba(0, 220, 255, 1);
  }
}

.djedi-overlay {
  background-color: rgba(0, 0, 0, 0.5);
  position: absolute;
  z-index: 10000;
  display: none;
}
