body {
    /*background-color: #333;*/
}

#image {
    display: none;
}

#dropzone {
    position: absolute;
    top: 68px;
    left: 0;
    width: 100%;
}

#dropzone section {
    /*width: 100%;*/
    margin: 20px;
    min-height: 290px;
    text-align: center;
    border: 3px dashed rgba(0, 0, 0, 0.5);
    line-height: 270px;
    padding: 0;
}

#dropzone section.drag {
    -webkit-transition: background-color 0.1s ease-in;
       -moz-transition: background-color 0.1s ease-in;
        -ms-transition: background-color 0.1s ease-in;
         -o-transition: background-color 0.1s ease-in;
            transition: background-color 0.1s ease-in;
    background-color: rgba(0, 0, 0, 0.2);
}

#dropzone section.drag-over {
    -webkit-transition: background-color 0.1s ease-in;
       -moz-transition: background-color 0.1s ease-in;
        -ms-transition: background-color 0.1s ease-in;
         -o-transition: background-color 0.1s ease-in;
            transition: background-color 0.1s ease-in;
    background-color: rgba(0, 58, 75, 0.5);
}

#dropzone section.error {
    background-color: rgba(75, 0, 39, 0.5);
}

#dropzone section.drag .drop,
#dropzone section.drag .uploading,
#dropzone section.drag-over .drag,
#dropzone section.drag-over .uploading,
#dropzone section.drop .drag,
#dropzone section.drop .drop {
    display: none;
}

#dropzone section.drag-over .drop,
#dropzone section.drop .uploading {
    display: inline;
}

#preview {
    width: 100%;
    /*min-height: 200px;*/
    margin-bottom: 20px;
}

#preview img {
}

#preview img.original {
    max-width: 100%;
    max-height: 290px;
    /*height: 200px;*/
}
