@import "variables.less";

@body-shadow: inset 20px 0 20px -20px black;

@navbar-default-shadow: 0px 1px 2px #111;

@nav-tabs-color: #666;
@nav-tabs-hover-color: #999;
@nav-tabs-active-color: #eee;

@editor-title-color: @text-color;
@editor-title-bg: rgba(0,0,0,0.25);
@editor-title-shadow: 0px 1px 2px #111;

@node-title-bg: darken(@body-bg, 2%);
